#!/bin/bash

#author				: hennes (jm@rapidrabbit.de)
#last changed		: 01-august-2007

#package			: dangerdeep
#homepage			: http://dangerdeep.sourceforge.net/
#source location	: http://belnet.dl.sourceforge.net/sourceforge/dangerdeep/dangerdeep-0.3.0.tar.gz
#data location		: http://kent.dl.sourceforge.net/sourceforge/dangerdeep/dangerdeep-data-0.3.0.zip
#dependencies		: coreutils,cxxlibs,directfb,expat,fftw,fontconfig,freetype,gcc,gcc-g++,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,perl,sdl,sysfsutils,utempter,xorg,xterm,zlib

# ----- credentials
softname="dangerdeep"
softversion="0.3.0"
srcurl="http://belnet.dl.sourceforge.net/sourceforge/dangerdeep/dangerdeep-0.3.0.tar.gz"
daturl="http://kent.dl.sourceforge.net/sourceforge/dangerdeep/dangerdeep-data-0.3.0.zip"
arch=i686
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/icons/hicolor/16x16/apps
mkdir -p $dest/usr/share/icons/hicolor/22x22/apps
mkdir -p $dest/usr/share/icons/hicolor/24x24/apps
mkdir -p $dest/usr/share/icons/hicolor/32x32/apps
mkdir -p $dest/usr/share/icons/hicolor/36x36/apps
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
mkdir -p $dest/usr/share/icons/hicolor/128x128/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/man/man6
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
          |-----handy-ruler------------------------------------------------------|
dangerdeep: dangerdeep (World War II german submarine simulator)
dangerdeep:
dangerdeep: Danger from the Deep (known as dangerdeep or DftD) is a free (as in
dangerdeep: free speech), Open Source World War II german submarine simulator.
dangerdeep:
dangerdeep:
dangerdeep:
dangerdeep:
dangerdeep:
dangerdeep:
dangerdeep:
EOF

# ----- get & extract data-archive
datdir=$builddir/data
rm -rf $datdir
if [ -f $softname-data-$softversion.zip ]; then
   echo "looking for data-file .. found"
else
   echo "looking for data-file .. none found"
   wget -c $daturl
fi
unzip $softname-data-$softversion.zip

# ----- extract source-archive
srcdir=$softname-$softversion
rm -rf $srcdir
if [ -f $softname-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -zxvf $softname-$softversion.tar.gz

# ----- set target-permissions
cd $datdir
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
cd $builddir/$srcdir
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- scons-build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
scons datadir=/usr/share/$softname arch=i686

# ----- copy files
cp ./build/linux/dangerdeep $dest/usr/bin
rm $builddir/data/LICENSE
cp -R $builddir/data/* $dest/usr/share/$softname

# ----- add default-files
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
	CREDITS ChangeLog INSTALL LICENSE README ./doc/*.pdf ./doc/*.txt \
	$dest/usr/doc/$softname-$softversion

# ----- copy man-files
cp ./doc/man/* $dest/usr/man/man6

# ----- treat icon files
tar -jxvf $builddir/icons.tar.bz2 --directory=$builddir
mv $builddir/icon-$softname-16.png $dest/usr/share/icons/hicolor/16x16/apps/$softname.png
mv $builddir/icon-$softname-22.png $dest/usr/share/icons/hicolor/22x22/apps/$softname.png
mv $builddir/icon-$softname-24.png $dest/usr/share/icons/hicolor/24x24/apps/$softname.png
mv $builddir/icon-$softname-32.png $dest/usr/share/icons/hicolor/32x32/apps/$softname.png
mv $builddir/icon-$softname-36.png $dest/usr/share/icons/hicolor/36x36/apps/$softname.png
mv $builddir/icon-$softname-48.png $dest/usr/share/icons/hicolor/48x48/apps/$softname.png
mv $builddir/icon-$softname-64.png $dest/usr/share/icons/hicolor/64x64/apps/$softname.png
mv $builddir/icon-$softname-128.png $dest/usr/share/icons/hicolor/128x128/apps/$softname.png
cp $builddir/icons.tar.bz2 $destsrc

# ----- make .desktop-files
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Danger from the deep
Comment=World War II german submarine simulator
Comment[de]=Simulator für U-Boote aus dem 2. Weltkrieg
Exec=dangerdeep --res 800*600
Icon=dangerdeep
Terminal=false
Type=Application
Categories=Game;Simulation;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
for mandir in $(find . -name man -type d) ; do
	if [ -d $mandir ]; then
		( cd $mandir
		  find . -type f -name "*.?" -exec gzip -9 {} \;
		)
	fi
done
	
# ----- packaging
chown -R root.root $dest/usr/bin
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $package.dep
coreutils,cxxlibs,directfb,expat,fftw,fontconfig,freetype,gcc,gcc-g++,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,perl,sdl,sysfsutils,utempter,xorg,xterm,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
